/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : A0cFB                                                                 *
 *                                                                                *
 * Description:                                                                   *
 *      Prediction of forward-backward asymmetry of c-quarks                      *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: A0cFB.cxx,v 1.17 2007/10/24 14:44:34 mgoebel Exp $
 **********************************************************************************/
#include "GSM/A0cFB.h"
#include "GSM/Z0Base.h"

#include "Gfitter/GMath.h"
#include "Gfitter/GTypes.h"

ClassImp(GSM::A0cFB)

GSM::A0cFB::A0cFB() : SMTheoryBuilder()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );
}

Double_t GSM::A0cFB::GetTheoryPrediction()
{
   Double_t Ratio_e = 1.0 - 4.0*GetZ0Theory().GetSin2Eff(Gfitter::GTypes::kElectron);
   Double_t Ratio_c = 1.0 - 4.0*Gfitter::GMath::TwoThird()*GetZ0Theory().GetSin2Eff(Gfitter::GTypes::kCharm);

   Double_t a0cfc = 3*( Ratio_e/(1+Ratio_e*Ratio_e)*Ratio_c/(1+Ratio_c*Ratio_c) ); 
   
   return a0cfc;
}
