/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : A0lepFB                                                               *
 *                                                                                *
 * Description:                                                                   *
 *      Prediction of forward-backward asymmetry of leptons                       *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: A0lepFB.cxx,v 1.5 2007/10/24 14:44:34 mgoebel Exp $
 **********************************************************************************/
#include "GSM/A0lepFB.h"
#include "GSM/Z0Base.h"

#include "Gfitter/GTypes.h"

ClassImp(GSM::A0lepFB)

GSM::A0lepFB::A0lepFB() : SMTheoryBuilder()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );
}

Double_t GSM::A0lepFB::GetTheoryPrediction()
{
   Double_t Ratio_e = 1.0 - 4.0*GetZ0Theory().GetSin2Eff(Gfitter::GTypes::kElectron);

   Double_t a0lepfb = 3*( Ratio_e/(1+Ratio_e*Ratio_e)*Ratio_e/(1+Ratio_e*Ratio_e) ); 
    
   return a0lepfb;
}
