/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : Ac                                                                    *
 *                                                                                *
 * Description:                                                                   *
 *      Asymmetry paramter of the c-quarks                                        *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: Ac.cxx,v 1.18 2007/10/24 14:44:34 mgoebel Exp $
 **********************************************************************************/
#include "GSM/Ac.h"
#include "GSM/Z0Base.h"

#include "Gfitter/GMath.h"
#include "Gfitter/GTypes.h"

ClassImp(GSM::Ac)

GSM::Ac::Ac() : SMTheoryBuilder()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );
}

Double_t GSM::Ac::GetTheoryPrediction()
{   
   Double_t Ratio_c = 1.0 - 4.0*Gfitter::GMath::TwoThird()*GetZ0Theory().GetSin2Eff(Gfitter::GTypes::kCharm);

   Double_t ac = 2*Ratio_c/(1+Ratio_c*Ratio_c); 
 
   return ac;
}
