/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : Alep                                                                  *
 *                                                                                *
 * Description:                                                                   *
 *      Asymmetry paramter of leptons                                             *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: Alep.cxx,v 1.6 2007/10/24 14:44:34 mgoebel Exp $
 **********************************************************************************/
#include "GSM/Alep.h"
#include "GSM/Z0Base.h"

#include "Gfitter/GTypes.h"

using namespace Gfitter;

ClassImp(GSM::Alep)

GSM::Alep::Alep() : SMTheoryBuilder()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );
}

Double_t GSM::Alep::GetTheoryPrediction()
{
   Double_t Ratio_e = 1.0 - 4.0*GetZ0Theory().GetSin2Eff(Gfitter::GTypes::kElectron);
  
   Double_t alep = 2*(Ratio_e)/(1 + Ratio_e*Ratio_e);  
    
   return alep;
}
