/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : AlphaQCDAtQ                                                           *
 *                                                                                *
 * Description:                                                                   *
 *      Theory for strong coupling constant at scale Q                            *
 *      Two options: take alphasMZ from Data-Card and compute lambdaMS5           *
 *                   take lambdaMS5 and fit it with AlphaQCDAtQ                   *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Johannes Haller <johannes.haller@desy.de>  - Uni HH, Germany              *
 *      Martin Goebel   <martin.goebel@desy.de>  - Uni HH, Germany                *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: AlphaQCDAtQ.h,v 1.1 2007/10/11 14:52:58 haller Exp $
 **********************************************************************************/
#ifndef GSM_AlphaQCDAtQ
#define GSM_AlphaQCDAtQ

#include "Gfitter/GTheory.h"

#include "GSM/RunningAlphaQCD.h"

class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class AlphaQCDAtQ : public Gfitter::GTheory  {

   public:
      
      AlphaQCDAtQ();
      virtual ~AlphaQCDAtQ() {}

      Double_t GetTheoryPrediction();

      void Initialise();

   protected:
    
      // reference to AlphasRunning
      RunningAlphaQCD& GetAlphasRun() const { return (RunningAlphaQCD&)*t_AlphasRun; }
      Gfitter::GTheoryRef    t_AlphasRun; 
      
      Gfitter::GParameterRef p_MZ;
   
      Double_t m_scale;

      ClassDef(AlphaQCDAtQ,0)
   };
}

#endif
