/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : GammaWtot                                                             *
 *                                                                                *
 * Description:                                                                   *
 *      Prediction of the total Z width                                           *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *      Andreas Hoecker <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: GammaZtot.cxx,v 1.4 2007/10/24 14:44:34 mgoebel Exp $
 **********************************************************************************/
#include "GSM/GammaZtot.h"
#include "GSM/Z0Base.h"

ClassImp(GSM::GammaZtot)

GSM::GammaZtot::GammaZtot() : SMTheoryBuilder()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );
}

Double_t GSM::GammaZtot::GetTheoryPrediction()
{   
   Double_t GaZnu  = GetZ0Theory().GetGaZneutrino(); 
   Double_t GaZe   = GetZ0Theory().GetGaZelectron();  
   Double_t GaZmu  = GetZ0Theory().GetGaZmuon(); 
   Double_t GaZtau = GetZ0Theory().GetGaZtau();
   Double_t GaZu   = GetZ0Theory().GetGaZup();  
   Double_t GaZd   = GetZ0Theory().GetGaZdown();  
   Double_t GaZs   = GetZ0Theory().GetGaZstrange();  
   Double_t GaZc   = GetZ0Theory().GetGaZcharm();  
   Double_t GaZb   = GetZ0Theory().GetGaZbottom();  
      
   Double_t gaztot = 3.0*GaZnu + GaZe + GaZmu + GaZtau + GaZu + GaZd + GaZs + GaZc + GaZb;    
      
   return gaztot;
}
