/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : HiggsTheoryBound                                                      *
 *                                                                                *
 * Description:                                                                   *
 *      This base class implements strict (!) bounds on the Higgs boson mass,     *
 *      where strict means MH >(<) MH_critical gets a infinite contribution       *
 *      to the chi-squared                                                        *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker  <andreas.hoecker@cern.ch>  - CERN, Switzerland           *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: HiggsTheoryBound.h,v 1.4 2007/09/26 13:43:30 mgoebel Exp $ 
**********************************************************************************/

#ifndef GSM_HiggsTheoryBound
#define GSM_HiggsTheoryBound

#include "Gfitter/GTheory.h"

class TGraph;

namespace GSM {

   class MH;
   class Gfitter::GTheoryRef;

   class HiggsTheoryBound : public Gfitter::GTheory {

   public:
      
      HiggsTheoryBound();
      ~HiggsTheoryBound() {}      

      // Theory Prediction
      Double_t GetTheoryPrediction();

      // Initialise coefficients
      virtual void Initialise();
      
   protected:

      enum BoundType { kNone = 0, kLower, kUpper };

      // provide critical mass and determine whether lower or upper bound
      BoundType m_boundType;      
      virtual Double_t GetCriticalMass() = 0;      

      // reference to Higgs mass
      GSM::MH& GetMH() const{ return (GSM::MH&)*t_MH; }
      Gfitter::GTheoryRef t_MH;

      // parameters from the Data-Card
      Gfitter::GParameterRef p_Log10LambdaCutoff;

      // read theories from files
      const TGraph* GetGraphFromFile( const TString& fname ) const;

   private:

      void CalculateVariables();

      Int_t m_sign; // this is the sign corresponding to the bound

      ClassDef(HiggsTheoryBound,0)
   };
}

#endif
