/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : HiggsThermMetastabilityBound                                          *
 *                                                                                *
 * Description:                                                                   *
 *      Implementation                                                            *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker  <andreas.hoecker@cern.ch>  - CERN, Switzerland           *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: HiggsThermMetastabilityBound.h,v 1.4 2007/09/26 13:43:30 mgoebel Exp $ 
**********************************************************************************/

#include "TMath.h"
#include "Riostream.h"
#include "TGraph.h"

#include "Gfitter/GMath.h"

#include "GSM/HiggsThermMetastabilityBound.h"

using namespace Gfitter;

ClassImp(GSM::HiggsThermMetastabilityBound)

GSM::HiggsThermMetastabilityBound::HiggsThermMetastabilityBound() 
   : HiggsTheoryBound()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );

   BookParameter( "mt",                  &p_mt );   

   BookTheory   ( "GSM::AlphaQCDAtQ/MZ", &t_AlphasMZ ); 
}

void GSM::HiggsThermMetastabilityBound::Initialise()
{
   m_boundType = kLower;
   HiggsTheoryBound::Initialise();
}

Double_t GSM::HiggsThermMetastabilityBound::GetCriticalMass()
{
   // units in GeV
   Double_t MHc = 0;

   // Eq (6) from our paper
   MHc = ( 122.0 + 3.0*(p_mt - 173.1)/1.3 - 2.3*(GetAlphasMZ() - 0.1193)/0.0028 );
   
   return MHc;
}
