/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : HiggsTrivialityBound                                                  *
 *                                                                                *
 * Description:                                                                   *
 *      Implementation                                                            *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker  <andreas.hoecker@cern.ch>  - CERN, Switzerland           *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: HiggsTrivialityBound.h,v 1.4 2007/09/26 13:43:30 mgoebel Exp $ 
**********************************************************************************/

#include "TMath.h"
#include "Riostream.h"

#include "Gfitter/GMath.h"
#include "TGraph.h"

#include "GSM/HiggsTrivialityBound.h"

#define UseHighBound__ kTRUE

using namespace Gfitter;

ClassImp(GSM::HiggsTrivialityBound)

GSM::HiggsTrivialityBound::HiggsTrivialityBound() 
   : HiggsTheoryBound(),
     m_pb_ref(0)
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );

   BookParameter( "mt",                  &p_mt );   
   BookTheory   ( "GSM::AlphaQCDAtQ/MZ", &t_AlphasMZ ); 
}

void GSM::HiggsTrivialityBound::Initialise()
{
   m_boundType = kUpper;
   HiggsTheoryBound::Initialise();

   // Reference: data files by Jose Espinosa, U. Penn
   m_pb_ref = GetGraphFromFile( (UseHighBound__ ? "datafiles/pbH.dat" : "datafiles/pbL.dat") );
}

Double_t GSM::HiggsTrivialityBound::GetCriticalMass()
{
   // units in GeV
   Double_t MHc = 0;

   // Reference: data files by Jose Espinosa, U. Penn
   MHc = m_pb_ref->Eval( p_Log10LambdaCutoff );  

   // Eq (3) from our paper
   Double_t as = GetAlphasMZ();
   MHc += ( 0.7*(p_mt - 173.1)/1.3 - 0.4*(as - 0.1193)/0.0028 );      

   return MHc;
}
