/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : HiggsTrivialityBound                                                  *
 *                                                                                *
 * Description:                                                                   *
 *      Bound obtained from triviality requirement (Landau pole)                  *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Andreas Hoecker  <andreas.hoecker@cern.ch>  - CERN, Switzerland           *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: HiggsTrivialityBound.h,v 1.4 2007/09/26 13:43:30 mgoebel Exp $ 
**********************************************************************************/

#ifndef GSM_HiggsTrivialityBound
#define GSM_HiggsTrivialityBound

#include "GSM/HiggsTheoryBound.h"

class TGraph;

namespace GSM {

   class HiggsTrivialityBound : public GSM::HiggsTheoryBound {

   public:
      
      HiggsTrivialityBound();
      ~HiggsTrivialityBound() {}      

      // Initialise coefficients
      void Initialise();
      
   protected:

      Gfitter::GParameterRef p_mt;

      Gfitter::GTheory&      GetAlphasMZ() const { return (Gfitter::GTheory&)*t_AlphasMZ; }      
      Gfitter::GTheoryRef    t_AlphasMZ; 

      const TGraph*          m_pb_ref; // graph for triviality bound - reference

      Double_t GetCriticalMass();

   private:

      ClassDef(HiggsTrivialityBound,0)
   };
}

#endif
