/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : MW                                                                    *
 *                                                                                *
 * Description:                                                                   *
 *      Prediction of W mass                                                      *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *      Andreas Hoecker <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: MW.h,v 1.19 2008/05/18 15:51:12 mgoebel Exp $
 **********************************************************************************/
#ifndef GSM_MW
#define GSM_MW

#include "Gfitter/GTheory.h"

class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class MH;
   class DAlphaQED;

   class MW : public Gfitter::GTheory {

   public:
      
      MW();
      ~MW() {}

      // Theory Prediction
      Double_t GetTheoryPrediction();

      // Initialise coefficients
      void Initialise();

   protected:
    
      // parameters from the Data-Card
      Gfitter::GParameterRef p_mt;
      Gfitter::GParameterRef p_MZ;
      Gfitter::GParameterRef p_GF;
      Gfitter::GParameterRef p_DeltaMW_Scale;

      // reference to DAlphaQED
      DAlphaQED& GetDAlphaQED() const { return (DAlphaQED&)*t_DAlphaQED; }      
      Gfitter::GTheoryRef    t_DAlphaQED; 
       
      // reference to AlphasMZ
      Gfitter::GTheory& GetAlphasMZ() const { return (Gfitter::GTheory&)*t_AlphasMZ; } 
      Gfitter::GTheoryRef    t_AlphasMZ; 

      // reference to Higgs mass
      GSM::MH& GetMH() const{ return (GSM::MH&)*t_MH; }
      Gfitter::GTheoryRef t_MH;

      // coefficients for the parameterized equation
      Double_t m_MW0;
      Double_t m_c1;
      Double_t m_c2;
      Double_t m_c3;
      Double_t m_c4; 
      Double_t m_c5;
      Double_t m_c6;
      Double_t m_c7;
      Double_t m_c8;
      Double_t m_c9;
      Double_t m_c10;
      Double_t m_c11;

      Bool_t m_logMH;

      ClassDef(MW,0)
   };
}

#endif
