/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : MWTree                                                                *
 *                                                                                *
 * Description:                                                                   *
 *      Prediction of W mass                                                      *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *      Andreas Hoecker <Andreas.Hocker@cern.ch> - CERN, Switzerland              *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: MWTree.h,v 1.19 2008/05/18 15:51:12 mgoebel Exp $
 **********************************************************************************/
#ifndef GSM_MWTree
#define GSM_MWTree

#include "Gfitter/GTheory.h"

class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class DAlphaQED;

   class MWTree : public Gfitter::GTheory {

   public:
      
      MWTree();
      ~MWTree() {}

      // Theory Prediction
      Double_t GetTheoryPrediction();

      // Initialise coefficients
      void Initialise();

   protected:
    
      // parameters from the Data-Card
      Gfitter::GParameterRef p_MZ;
      Gfitter::GParameterRef p_GF;

      // reference to DAlphaQED
      DAlphaQED& GetDAlphaQED() const { return (DAlphaQED&)*t_DAlphaQED; }      
      Gfitter::GTheoryRef    t_DAlphaQED; 
       
      ClassDef(MWTree,0)
   };
}

#endif
