/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : R0b                                                                   *
 *                                                                                *
 * Description:                                                                   *
 *       Ratio of the bottoms partial Z width to all hadrons                      *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: R0b.cxx,v 1.19 2007/10/24 14:44:34 mgoebel Exp $
 **********************************************************************************/
#include "GSM/R0b.h"
#include "GSM/Z0Base.h"

ClassImp(GSM::R0b)

GSM::R0b::R0b() : SMTheoryBuilder()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );
}

Double_t GSM::R0b::GetTheoryPrediction()
{   
   Double_t GaZu = GetZ0Theory().GetGaZup();
   Double_t GaZd = GetZ0Theory().GetGaZdown();
   Double_t GaZs = GetZ0Theory().GetGaZstrange();
   Double_t GaZc = GetZ0Theory().GetGaZcharm();
   Double_t GaZb = GetZ0Theory().GetGaZbottom();
       
   Double_t r0b = GaZb/(GaZu + GaZd + GaZs + GaZc + GaZb);

   return r0b;
}
