/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : SMTheoryBuilder                                                       *
 *                                                                                *
 * Description:                                                                   *
 *      SM theory builder                                                         *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: SMTheoryBuilder.cxx,v 1.5 2007/09/26 13:43:30 mgoebel Exp $
 **********************************************************************************/
#include "TString.h"

#include "Gfitter/GVariable.h"
#include "Gfitter/GStore.h"
#include "Gfitter/GTheoryRef.h"

#include "GSM/SMTheoryBuilder.h"

using namespace Gfitter;

ClassImp(GSM::SMTheoryBuilder)

GSM::SMTheoryBuilder::SMTheoryBuilder()
   : Gfitter::GTheory()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );

   const TString& theory = gStore()->GetVariable( "GSMFlags::Theory" )->GetStringValue();
   m_logger << kINFO << "Using Theory type: \"" << theory << "\"" << GEndl;
   
   if( theory == "ZFitter" ){
      BookTheory( "GSM::Z0ZFitter", &m_z0Theory );
      BookTheory( "GSM::WZFitter",  &m_wTheory );
   }
   else if( theory == "Parametrisation"){
      BookTheory( "GSM::Z0Parametrisation", &m_z0Theory );
      BookTheory( "GSM::WParametrisation",  &m_wTheory );
   }
   else {
      m_logger << kFATAL << "unknown value for \"GSMFlags::Theory\": \"" << theory << "\""
               << ". Possible are: \"ZFitter\" or \"Parametrisation\"" << GEndl;
   }
}
