/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : Sigma0had                                                             *
 *                                                                                *
 * Description:                                                                   *
 *      Prediction of hadronic cross-section                                      *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: Sigma0had.cxx,v 1.6 2007/10/25 13:07:28 haller Exp $
 **********************************************************************************/
#include "TMath.h"

#include "Gfitter/GMath.h"

#include "GSM/Sigma0had.h"
#include "GSM/Z0Base.h"

ClassImp(GSM::Sigma0had)

GSM::Sigma0had::Sigma0had() : SMTheoryBuilder()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );

   BookParameter( "MZ" , &m_MZ );
}

Double_t GSM::Sigma0had::GetTheoryPrediction()
{   
   Double_t GaZe   = GetZ0Theory().GetGaZelectron();
   Double_t GaZmu  = GetZ0Theory().GetGaZmuon();
   Double_t GaZtau = GetZ0Theory().GetGaZtau();
   Double_t GaZnu  = GetZ0Theory().GetGaZneutrino();
   Double_t GaZu   = GetZ0Theory().GetGaZup();
   Double_t GaZd   = GetZ0Theory().GetGaZdown();
   Double_t GaZs   = GetZ0Theory().GetGaZstrange();
   Double_t GaZc   = GetZ0Theory().GetGaZcharm();
   Double_t GaZb   = GetZ0Theory().GetGaZbottom();
  
   Double_t GaZhad = GaZu + GaZd + GaZs + GaZc + GaZb;    
   Double_t GaZtot = 3.0*GaZnu + GaZe + GaZmu + GaZtau + GaZhad;
   
   // and conversion from GeV to nano-barn
   Double_t sigma0had = ( 12.0*TMath::Pi()*GaZe*
                          GaZhad/Gfitter::GMath::IPow(GaZtot*m_MZ,2)*
                          Gfitter::GMath::IPow(1.97327,2)*1e5 ); 
   
   return sigma0had;
   
   
}
