/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : WBase                                                                 *
 *                                                                                *
 * Description:                                                                   *
 *      W Base class for W width                                                  *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: WBase.h,v 1.7 2007/08/27 22:13:08 hoecker Exp $
 **********************************************************************************/
#ifndef GSM_WBase
#define GSM_WBase

#include <complex>

#include "Gfitter/GAuxTheory.h"

class Gfitter::GReference;
class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class Vertex;
   class ZFitterFermionPart;
   class ZFitterBosonPart;
   class RadiatorFunctions;

   class WBase : public Gfitter::GAuxTheory {

   public:
      
      WBase();
      virtual ~WBase() {}
    
      // not used
      void Initialise() {};

      virtual Double_t GetGammaW() = 0;
      
   protected:
      
      // reference to W mass
      Gfitter::GTheory& GetMW() const { return (Gfitter::GTheory&)*m_MW; }      
      Gfitter::GTheoryRef    m_MW; 

      // Data-Card members
      Gfitter::GParameterRef p_MZ; 
      Gfitter::GParameterRef p_GF; 
      
      Double_t m_gammaW;

   private:

      ClassDef(WBase,0)
   };
}

#endif
