/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : WParametrisation                                                      *
 *                                                                                *
 * Description:                                                                   *
 *      W Boson decay / total width                                               *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: WParametrisation.h,v 1.7 2007/08/27 22:13:08 hoecker Exp $
 **********************************************************************************/
#ifndef GSM_WParametrisation
#define GSM_WParametrisation

#include <complex>

#include "GSM/WBase.h"
#include "GSM/MH.h"

class Gfitter::GReference;
class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class WParametrisation : public WBase {

   public:
      
      WParametrisation();
      virtual ~WParametrisation() {}
    
      // not used
      void Initialise() {};

      Double_t GetGammaW(){  Update(); return m_gammaW; };
   
   protected:
      
      // update of flags in case of parameter change
      void UpdateLocalFlags( Gfitter::GReference& ref );
   
      // update parameters
      void Update();
      
      // reference to Higgs mass
      GSM::MH& GetMH() const{ return (GSM::MH&)*t_MH; }
      Gfitter::GTheoryRef t_MH;
      
      // reference to AlphasMZ
      Gfitter::GTheory& GetAlphasMZ() const { return (Gfitter::GTheory&)*t_AlphasMZ; }      
      Gfitter::GTheoryRef    t_AlphasMZ; 

      Bool_t m_logMH;
    
   private:

      // boolean flags to track recomputation
      Bool_t m_isUpToDate_Update; 

      ClassDef(WParametrisation,0)
   };
}

#endif
