/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : WZFitter                                                              *
 *                                                                                *
 * Description:                                                                   *
 *      Auxiliary Theory for electroweak formfactor for W decay                   *
 *      W Boson decay / total width                                               *
 *                                                                                *
 * Source:                                                                        *
 *      The Standard Model in the Making, Oxford 1999                             *
 *      Zfitter package dizet6_42.f                                               *
 *                                                                                *
 * Authors:                                                                       *
 *      See gsm/AUTHORS file                                                      *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: WZFitter.h,v 1.7 2007/08/27 22:13:08 hoecker Exp $
 **********************************************************************************/
#ifndef GSM_WZFitter
#define GSM_WZFitter

#include <complex>

#include "GSM/WBase.h"

class Gfitter::GReference;
class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class ZFitterVertex;
   class ZFitterFermionPart;
   class ZFitterBosonPart;
   class RadiatorFunctions;

   class WZFitter : public WBase {

   public:
      
      WZFitter();
      virtual ~WZFitter() {}
    
      // not used
      void Initialise() {};

      Double_t GetGammaW(){  Update(); return m_gammaW; };

   protected:
      
      // update of flags in case of parameter change
      void UpdateLocalFlags( Gfitter::GReference& ref );
   
      // update parameters
      void Update();

      // accessors
      Double_t GetRhoW( Double_t ch );

      // reference to Vertex
      ZFitterVertex& GetVertex() const { return (ZFitterVertex&)*t_Vertex; }      
      Gfitter::GTheoryRef    t_Vertex; 
     
      // reference to ZFitterFermionPart
      ZFitterFermionPart& GetFermionPart() const { return (ZFitterFermionPart&)*t_fermionPart; }
      Gfitter::GTheoryRef    t_fermionPart; 
     
      // reference to ZFitterBosonPart
      ZFitterBosonPart& GetBosonPart() const { return (ZFitterBosonPart&)*t_bosonPart; }      
      Gfitter::GTheoryRef    t_bosonPart; 

      // reference to radiator function
      RadiatorFunctions& GetRadFun() const { return (RadiatorFunctions&)*t_RadFun; }      
      Gfitter::GTheoryRef    t_RadFun;

      // updated member variables
      Double_t m_R;
           
      // bosonic + fermionic corrections
      Double_t m_W_MW;
      Double_t m_W0;
      Double_t m_WF_MW;

   private:

      // boolean flags to track recomputation
      Bool_t m_isUpToDate_Update; 

      ClassDef(WZFitter,0)
   };
}

#endif
