/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : Z0Base                                                                *
 *                                                                                *
 * Description:                                                                   *
 *      Base class for EW fits                                                    *
 *                                                                                *
 * Sources:                                                                       *
 *      The Standard Model in the Making, Oxford 1999                             *
 *                                                                                *
 * Authors (alphabetical):                                                        *
 *      Martin Goebel   <martin.goebel@desy.de>  - DESY, Germany                  *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: Z0Base.cxx,v 1.6 2007/10/02 09:26:30 mgoebel Exp $
 **********************************************************************************/
#include "TMath.h"

#include "Gfitter/GMath.h"
#include "Gfitter/GConstants.h"
#include "Gfitter/GParameterRef.h"
#include "Gfitter/GTheoryRef.h"

#include "GSM/Sin2ThetaF.h"
#include "GSM/DAlphaQED.h"
#include "GSM/MH.h"


#include "GSM/Z0Base.h"

using namespace Gfitter;

ClassImp(GSM::Z0Base)

GSM::Z0Base::Z0Base()
   : Gfitter::GAuxTheory()
{
   SetTheoryName( GetName() );
   SetExistDerivative( kFALSE );

   BookParameter( "mt", &p_mt );  
   BookParameter( "MZ", &p_MZ );   
   BookParameter( "GF", &p_GF );

   BookTheory   ( "GSM::MH"                    , &t_MH );
   BookTheory   ( "GSM::AlphaQCDAtQ/MZ"        , &t_AlphasMZ );   
   BookTheory   ( "GSM::DAlphaQED"             , &t_DAlphaQED );
   BookTheory   ( "GSM::Sin2ThetaF"            , &t_sineff );
}




