/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : ZFitterBosonPart                                                      *
 *                                                                                *
 * Description:                                                                   *
 *      Auxiliary Theory for bosonic part of self energies                        *
 *      one loop core of ZFitter option                                           *
 *                                                                                *
 * References:                                                                    *
 *      The Standard Model in the Making                                          *
 *      Nucl. Phys. B197 (1982) 1-44 / first summary of one loop core             *
 *      hep-ph/9709299, hep-ph/9908433                                            *
 *      ZFITTER package dizet6_42.f                                               *
 *                                                                                *
 * Authors:                                                                       *
 *      See gsm/AUTHORS file                                                      *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: ZFitterBosonPart.h,v 1.6 2008/05/18 15:51:12 mgoebel Exp $
 **********************************************************************************/
#ifndef GSM_ZFitterBosonPart
#define GSM_ZFitterBosonPart

#include <complex>
#include "Gfitter/GAuxTheory.h"

class Gfitter::GReference;
class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class MH;

   class ZFitterBosonPart : public Gfitter::GAuxTheory {
    
   public:
   
      ZFitterBosonPart();
      virtual ~ZFitterBosonPart() {}
      
      // bosonic part of self engeries
      // accessors, downcast for using them
      std::complex<Double_t> GetZbAtMZ();
      std::complex<Double_t> GetZbFAtMZ();
      std::complex<Double_t> GetWbAt0();
      std::complex<Double_t> GetWbAtMW();
      std::complex<Double_t> GetMbPhoZAtMZ(); 
      std::complex<Double_t> GetWbFAtMW(); 

      // not used
      void Initialise() {}
         
   protected:

      // update of flags in case of parameter change
      void UpdateLocalFlags( Gfitter::GReference& ref );
   
      // update parameters
      void Update();

      // reference to W mass
      Gfitter::GTheory& GetMW() const { return (Gfitter::GTheory&)*t_MW; }      
      Gfitter::GTheoryRef    t_MW; 
      
      // reference to Higgs mass
      GSM::MH& GetMH() const{ return (GSM::MH&)*t_MH; }
      Gfitter::GTheoryRef t_MH;

      // Data-Card Parameters
      Gfitter::GParameterRef p_MZ; 
     
      // updated parameters
      Double_t m_R;
      Double_t m_rw;
      Double_t m_rz;
      
      std::complex<Double_t> m_L0;
      std::complex<Double_t> m_L1;
      std::complex<Double_t> m_L2;
      std::complex<Double_t> m_L3;
      std::complex<Double_t> m_L4;
      std::complex<Double_t> m_J1;
      std::complex<Double_t> m_J3;
  
      Bool_t m_logMH;

   private:

      // boolean flags to track recomputation
      Bool_t m_isUpToDate_Update; 

      ClassDef(ZFitterBosonPart,0)
   };
}

#endif
