/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : ZFitterQCDCorrection                                                  *
 *                                                                                *
 * Description:                                                                   *
 *      2 loopQCD Corrections to the effective weak couplings                     *
 *      in perturbative QCD                                                       *
 *      Nucl. Phys. B347 (1990) 86-104 by Kniehl                                  *
 *                                                                                *
 * Authors:                                                                       *
 *      See gsm/AUTHORS file                                                      *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: ZFitterQCDCorrections.h,v 1.9 2007/10/24 09:46:28 mgoebel Exp $
 **********************************************************************************/
#ifndef GSM_ZFitterQCDCorrections
#define GSM_ZFitterQCDCorrections

#include <complex>
#include "Gfitter/GAuxTheory.h"

class Gfitter::GReference;
class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {
  
   class AlphasRunning;
  
   class ZFitterQCDCorrections : public Gfitter::GAuxTheory {
    
   public:
     
      ZFitterQCDCorrections();
      virtual ~ZFitterQCDCorrections() {}

      void Initialise();
      
      std::complex<Double_t> GetKMQCD();
      std::complex<Double_t> GetRMQCD();
    
   protected: 
      
      // update of flags in case of parameter change
      void UpdateLocalFlags( Gfitter::GReference& ref );
   
      // update parameters
      void Update();
       
      // reference to W mass
      Gfitter::GTheory& GetMW() const { return (Gfitter::GTheory&)*t_MW; }      
      Gfitter::GTheoryRef    t_MW; 

      Gfitter::GParameterRef p_MZ;
      Gfitter::GParameterRef p_mt;

      std::complex<Double_t> m_kmQCD;
      std::complex<Double_t> m_rmQCD;
      std::complex<Double_t> m_cone;
      std::complex<Double_t> m_zeta3;

      std::complex<Double_t> KMQCD( const Double_t& MZ2, const Double_t& MW2, const Double_t& MT2, const Double_t& S ) const;
      std::complex<Double_t> RMQCD( const Double_t& MZ2, const Double_t& MW2, const Double_t& MT2, const Double_t& S ) const;
      std::complex<Double_t> CA1  ( const std::complex<Double_t>& CR ) const; 
      std::complex<Double_t> CV1  ( const std::complex<Double_t>& CR ) const;
      std::complex<Double_t> CF1  ( const std::complex<Double_t>& CX ) const;
            
   private:
      // boolean flags to track recomputation
      Bool_t m_isUpToDate_Update; 
      
      ClassDef(ZFitterQCDCorrections,0)
   };
}

inline std::complex<Double_t> GSM::ZFitterQCDCorrections::GetKMQCD()
{
   Update();
   return m_kmQCD;
}

inline std::complex<Double_t> GSM::ZFitterQCDCorrections::GetRMQCD()
{
   Update(); 
   return m_rmQCD;
}

#endif
