/**********************************************************************************
 * Project: GSM - Electroweak fitting package                                     *
 * Package: GSM                                                                   *
 * Class  : ZFitterVertex                                                         *
 *                                                                                *
 * Description:                                                                   *
 *      Auxiliary Theory for ZFitterVertex corrections                            *
 *                                                                                *
 * Source:                                                                        *
 *      hep-ph/9709229v1, hep-ph/9908433                                          *
 *      dizet6_42.f (ZFitter)                                                     *
 *                                                                                *
 * Authors:                                                                       *
 *      See gsm/AUTHORS file                                                      *
 *                                                                                *
 * File and Version Information:                                                  *
 * $Id: ZFitterVertex.h,v 1.6 2007/08/27 22:13:07 hoecker Exp $
 **********************************************************************************/
#ifndef GSM_ZFitterVertex
#define GSM_ZFitterVertex

#include <complex>

#include "Gfitter/GAuxTheory.h"

class Gfitter::GReference;
class Gfitter::GParameterRef;
class Gfitter::GTheoryRef;

namespace GSM {

   class ZFitterVertex : public Gfitter::GAuxTheory {

   public:
      
      ZFitterVertex();
      virtual ~ZFitterVertex() {}
     
      // not used
      void Initialise() {}

      // accessors, downcast forusing them
      std::complex<Double_t> GetV1ZZ();
      std::complex<Double_t> GetV1ZW();
      std::complex<Double_t> GetV2ZWW();
      Double_t               GetV1WZ();
      Double_t               GetV2WWZ();
      Double_t               GetVtb();
      
   protected:
      
      // update of flags in case of parameter change
      void UpdateLocalFlags( Gfitter::GReference& ref );
   
      // update parameters
      void Update();

      // reference to W mass
      Gfitter::GTheory& GetMW() const { return (Gfitter::GTheory&)*t_MW; }      
      Gfitter::GTheoryRef    t_MW; 
      
      // Data-Card members
      Gfitter::GParameterRef p_MZ; 
      Gfitter::GParameterRef p_mt; 
      
      // vertex function deals with imaginary part
      std::complex<Double_t> V1b( Double_t Q2, Double_t MV2 );
	 
      // for Z decay
      std::complex<Double_t> m_V1ZZ;
      std::complex<Double_t> m_V1ZW;
      std::complex<Double_t> m_V2ZWW;
      
      // for W decay
      Double_t m_V1WZ;
      Double_t m_V2WWZ;
      
      // additional top contribution
      Double_t m_Vtb;

   private:

      // boolean flags to track recomputation
      Bool_t m_isUpToDate_Update; 

      ClassDef(ZFitterVertex,0)
   };
}
//-----------------------inline functions for fast access-------------------------


inline std::complex<Double_t> GSM::ZFitterVertex::GetV1ZZ()
{
   Update();
   return m_V1ZZ;
}

inline std::complex<Double_t> GSM::ZFitterVertex::GetV1ZW()
{ 
   Update();
   return m_V1ZW;
}

inline std::complex<Double_t> GSM::ZFitterVertex::GetV2ZWW()
{
   Update();
   return m_V2ZWW;
}

inline Double_t GSM::ZFitterVertex::GetV1WZ()
{
   Update();
   return m_V1WZ;
}

inline Double_t GSM::ZFitterVertex::GetV2WWZ()
{
   Update();
   return m_V2WWZ;
}

inline Double_t GSM::ZFitterVertex::GetVtb()
{
   Update();
   return m_Vtb;
}

#endif


